## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Containers which contain hostels.
"""
import grok
from grok import index
from waeup.sirp.hostels.interfaces import IHostelsContainer
from waeup.sirp.utils.helpers import attrs_to_fields
from waeup.sirp.utils.logger import Logger

class HostelsContainer(grok.Container, Logger):
    """This is a container for all kind of hostels.
    """
    grok.implements(IHostelsContainer)
    grok.provides(IHostelsContainer)

    def __init__(self):
        super(HostelsContainer, self).__init__()
        return

    def archive(self, id=None):
        raise NotImplementedError()

    def clear(self, id=None, archive=True):
        raise NotImplementedError()

    def addHostel(self, hostel):
        """Add a hostel.
        """
        if not IHostel.providedBy(hostel):
            raise TypeError(
                'HostelsContainers contain only IHostel instances')
        self[hostel.hostel_id] = hostel
        return

    logger_name = 'waeup.sirp.${sitename}.hostels'
    logger_filename = 'hostels.log'

    def logger_info(self, ob_class, target, comment=None):
        """Get the logger's info method.
        """
        user = get_current_principal()
        if user is None:
            user = 'system'
        else:
            user = user.id
        self.logger.info('%s - %s - %s - %s' % (
                user, ob_class, target, comment))
        return
